@@ -23,6 +23,7 @@
 /* 
  * MT safe
  */
+#include "config.h"
 
 #include <be/kernel/image.h> /* image (aka DSO) handling functions... */
 
@@ -48,6 +49,9 @@
  * different image_id's. While this means that we don't have to worry about 
  * reference counts, it could lead to problems in the future....
  * richard.
+ *
+ * load_add_on() apparently does not support lazy or local binding.  Need
+ * to confirm that the actual behavior is non-lazy/local.  --ds
  */
 
 #include <Errors.h>
@@ -56,7 +60,8 @@
 /* --- functions --- */
 static gpointer
 _g_module_open (const gchar *file_name,
-		gboolean     bind_lazy)
+		gboolean     bind_lazy,
+		gboolean     bind_local)
 {
   image_id handle;
   
@@ -190,10 +195,10 @@ _g_module_build_path (const gchar *directory,
       if (strncmp (module_name, "lib", 3) == 0)
 	return g_strconcat (directory, "/", module_name, NULL);
       else
-	return g_strconcat (directory, "/lib", module_name, ".so", NULL);
+	return g_strconcat (directory, "/lib", module_name, "." G_MODULE_SUFFIX, NULL);
     }
   else if (strncmp (module_name, "lib", 3) == 0)
     return g_strdup (module_name);
   else
-    return g_strconcat ("lib", module_name, ".so", NULL);
+    return g_strconcat ("lib", module_name, "." G_MODULE_SUFFIX, NULL);
 }
